
from ..config import default


def basic_config(args, log, db):
    '''
# basic-config

    ch2 basic-config

Generate a simple initial configuration.

Please see the documentation at http://andrewcooke.github.io/choochoo/index
    '''
    default(db)
